==> jc-1.4.0.tar.gz: javax/swing/JRadioButton__24AccessibleJRadioButton.h <==
// public class javax.swing.JRadioButton$AccessibleJRadioButton

// class file dependencies
// @dep_class 61b24c22f38bff85 java_awt_Component__24AccessibleAWTComponent
// @dep_class 6d5f0a9d86bc5fc4 java_awt_Container__24AccessibleAWTContainer
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d2c97b9b1866e7b0 javax_accessibility_AccessibleContext
// @dep_class 3f25717f6c53c837 javax_swing_AbstractButton__24AccessibleAbstractButton
// @dep_class 32f620e3c8c75689 javax_swing_JComponent__24AccessibleJComponent
// @dep_class e9915bf3d8930742 javax_swing_JRadioButton__24AccessibleJRadioButton
// @dep_class 97d486940e7264b javax_swing_JToggleButton__24AccessibleJToggleButton

// header file dependencies
// @dep_header javax_swing_JToggleButton__24AccessibleJToggleButton

#include "javax/swing/JToggleButton__24AccessibleJToggleButton.h"

#ifndef _JC_javax_swing_JRadioButton__24AccessibleJRadioButton_H_
#define _JC_javax_swing_JRadioButton__24AccessibleJRadioButton_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_accessibility_AccessibleRole$object;
struct _jc_javax_swing_JRadioButton$object;

// Typedefs
typedef struct _jc_javax_swing_JRadioButton__24AccessibleJRadioButton$sub_refs	_jc_javax_swing_JRadioButton__24AccessibleJRadioButton$sub_refs;
typedef struct _jc_javax_swing_JRadioButton__24AccessibleJRadioButton$sub_nonrefs	_jc_javax_swing_JRadioButton__24AccessibleJRadioButton$sub_nonrefs;
typedef struct _jc_javax_swing_JRadioButton__24AccessibleJRadioButton$refs	_jc_javax_swing_JRadioButton__24AccessibleJRadioButton$refs;
typedef struct _jc_javax_swing_JRadioButton__24AccessibleJRadioButton$nonrefs	_jc_javax_swing_JRadioButton__24AccessibleJRadioButton$nonrefs;
typedef struct _jc_javax_swing_JRadioButton__24AccessibleJRadioButton$object	_jc_javax_swing_JRadioButton__24AccessibleJRadioButton$object;

typedef const struct _jc_javax_swing_JRadioButton__24AccessibleJRadioButton$vmethods	_jc_javax_swing_JRadioButton__24AccessibleJRadioButton$vmethods;
typedef const struct _jc_javax_swing_JRadioButton__24AccessibleJRadioButton$vtable	_jc_javax_swing_JRadioButton__24AccessibleJRadioButton$vtable;
typedef const struct _jc_javax_swing_JRadioButton__24AccessibleJRadioButton$vtype	_jc_javax_swing_JRadioButton__24AccessibleJRadioButton$vtype;

// Constructors
extern void _jc_javax_swing_JRadioButton__24AccessibleJRadioButton$method$_init$6589533da100e8ac(_jc_env *, struct _jc_javax_swing_JRadioButton__24AccessibleJRadioButton$object *, struct _jc_javax_swing_JRadioButton$object *);

// Virtual methods
extern struct _jc_javax_accessibility_AccessibleRole$object *_jc_javax_swing_JRadioButton__24AccessibleJRadioButton$method$getAccessibleRole$eaa05a502d0ede18(_jc_env *, struct _jc_javax_swing_JRadioButton__24AccessibleJRadioButton$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_JRadioButton__24AccessibleJRadioButton$method_info$getAccessibleRole$eaa05a502d0ede18;

// Virtual methods structure
struct _jc_javax_swing_JRadioButton__24AccessibleJRadioButton$vmethods {
	struct _jc_javax_accessibility_AccessibleRole$object	*(*getAccessibleRole$eaa05a502d0ede18)(_jc_env *, struct _jc_javax_swing_JRadioButton__24AccessibleJRadioButton$object *);
};

// Vtable
struct _jc_javax_swing_JRadioButton__24AccessibleJRadioButton$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_accessibility_AccessibleContext$vmethods	javax_accessibility_AccessibleContext;
	_jc_java_awt_Component__24AccessibleAWTComponent$vmethods	java_awt_Component__24AccessibleAWTComponent;
	_jc_java_awt_Container__24AccessibleAWTContainer$vmethods	java_awt_Container__24AccessibleAWTContainer;
	_jc_javax_swing_JComponent__24AccessibleJComponent$vmethods	javax_swing_JComponent__24AccessibleJComponent;
	_jc_javax_swing_AbstractButton__24AccessibleAbstractButton$vmethods	javax_swing_AbstractButton__24AccessibleAbstractButton;
	_jc_javax_swing_JToggleButton__24AccessibleJToggleButton$vmethods	javax_swing_JToggleButton__24AccessibleJToggleButton;
	_jc_javax_swing_JRadioButton__24AccessibleJRadioButton$vmethods	javax_swing_JRadioButton__24AccessibleJRadioButton;
};

// Vtype
struct _jc_javax_swing_JRadioButton__24AccessibleJRadioButton$vtype {
	_jc_type			type;
	_jc_javax_swing_JRadioButton__24AccessibleJRadioButton$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_JRadioButton__24AccessibleJRadioButton$sub_refs {
	struct _jc_javax_swing_JRadioButton$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_JRadioButton__24AccessibleJRadioButton$refs {
    _jc_javax_swing_JRadioButton__24AccessibleJRadioButton$sub_refs	javax_swing_JRadioButton__24AccessibleJRadioButton;
    _jc_javax_swing_JToggleButton__24AccessibleJToggleButton$sub_refs	javax_swing_JToggleButton__24AccessibleJToggleButton;
    _jc_javax_swing_AbstractButton__24AccessibleAbstractButton$sub_refs	javax_swing_AbstractButton__24AccessibleAbstractButton;
    _jc_javax_swing_JComponent__24AccessibleJComponent$sub_refs	javax_swing_JComponent__24AccessibleJComponent;
    _jc_java_awt_Container__24AccessibleAWTContainer$sub_refs	java_awt_Container__24AccessibleAWTContainer;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_refs	java_awt_Component__24AccessibleAWTComponent;
    _jc_javax_accessibility_AccessibleContext$sub_refs	javax_accessibility_AccessibleContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_JRadioButton__24AccessibleJRadioButton$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_JRadioButton__24AccessibleJRadioButton$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_accessibility_AccessibleContext$sub_nonrefs	javax_accessibility_AccessibleContext;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_nonrefs	java_awt_Component__24AccessibleAWTComponent;
    _jc_java_awt_Container__24AccessibleAWTContainer$sub_nonrefs	java_awt_Container__24AccessibleAWTContainer;
    _jc_javax_swing_JComponent__24AccessibleJComponent$sub_nonrefs	javax_swing_JComponent__24AccessibleJComponent;
    _jc_javax_swing_AbstractButton__24AccessibleAbstractButton$sub_nonrefs	javax_swing_AbstractButton__24AccessibleAbstractButton;
    _jc_javax_swing_JToggleButton__24AccessibleJToggleButton$sub_nonrefs	javax_swing_JToggleButton__24AccessibleJToggleButton;
    _jc_javax_swing_JRadioButton__24AccessibleJRadioButton$sub_nonrefs	javax_swing_JRadioButton__24AccessibleJRadioButton;
};

// Object instance structure
struct _jc_javax_swing_JRadioButton__24AccessibleJRadioButton$object {
	_jc_javax_swing_JRadioButton__24AccessibleJRadioButton$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_JRadioButton__24AccessibleJRadioButton$vtype	*vtype;
	_jc_javax_swing_JRadioButton__24AccessibleJRadioButton$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_JRadioButton__24AccessibleJRadioButton$vtype _jc_javax_swing_JRadioButton__24AccessibleJRadioButton$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_JRadioButton__24AccessibleJRadioButton, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_JRadioButton__24AccessibleJRadioButton$class_object;

#endif	/* _JC_javax_swing_JRadioButton__24AccessibleJRadioButton_H_ */

==> jc-1.4.5.tar.gz: javax/swing/JRadioButton__24AccessibleJRadioButton.h <==
// public class javax.swing.JRadioButton$AccessibleJRadioButton

// class file dependencies
// @dep_class e1ad6f3c35669e42 java_awt_Component__24AccessibleAWTComponent
// @dep_class 6d5f0a9d86bc5fc4 java_awt_Container__24AccessibleAWTContainer
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d2c97b9b1866e7b0 javax_accessibility_AccessibleContext
// @dep_class 3f25717f6c53c837 javax_swing_AbstractButton__24AccessibleAbstractButton
// @dep_class 32f620e3c8c75689 javax_swing_JComponent__24AccessibleJComponent
// @dep_class e9915bf3d8930742 javax_swing_JRadioButton__24AccessibleJRadioButton
// @dep_class 97d486940e7264b javax_swing_JToggleButton__24AccessibleJToggleButton

// header file dependencies
// @dep_header javax_swing_JToggleButton__24AccessibleJToggleButton

#include "javax/swing/JToggleButton__24AccessibleJToggleButton.h"

#ifndef _JC_javax_swing_JRadioButton__24AccessibleJRadioButton_H_
#define _JC_javax_swing_JRadioButton__24AccessibleJRadioButton_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_accessibility_AccessibleRole$object;
struct _jc_javax_swing_JRadioButton$object;

// Typedefs
typedef struct _jc_javax_swing_JRadioButton__24AccessibleJRadioButton$sub_refs	_jc_javax_swing_JRadioButton__24AccessibleJRadioButton$sub_refs;
typedef struct _jc_javax_swing_JRadioButton__24AccessibleJRadioButton$sub_nonrefs	_jc_javax_swing_JRadioButton__24AccessibleJRadioButton$sub_nonrefs;
typedef struct _jc_javax_swing_JRadioButton__24AccessibleJRadioButton$refs	_jc_javax_swing_JRadioButton__24AccessibleJRadioButton$refs;
typedef struct _jc_javax_swing_JRadioButton__24AccessibleJRadioButton$nonrefs	_jc_javax_swing_JRadioButton__24AccessibleJRadioButton$nonrefs;
typedef struct _jc_javax_swing_JRadioButton__24AccessibleJRadioButton$object	_jc_javax_swing_JRadioButton__24AccessibleJRadioButton$object;

typedef const struct _jc_javax_swing_JRadioButton__24AccessibleJRadioButton$vmethods	_jc_javax_swing_JRadioButton__24AccessibleJRadioButton$vmethods;
typedef const struct _jc_javax_swing_JRadioButton__24AccessibleJRadioButton$vtable	_jc_javax_swing_JRadioButton__24AccessibleJRadioButton$vtable;
typedef const struct _jc_javax_swing_JRadioButton__24AccessibleJRadioButton$vtype	_jc_javax_swing_JRadioButton__24AccessibleJRadioButton$vtype;

// Constructors
extern void _jc_javax_swing_JRadioButton__24AccessibleJRadioButton$method$_init$6589533da100e8ac(_jc_env *, struct _jc_javax_swing_JRadioButton__24AccessibleJRadioButton$object *, struct _jc_javax_swing_JRadioButton$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_javax_accessibility_AccessibleRole$object *_jc_javax_swing_JRadioButton__24AccessibleJRadioButton$method$getAccessibleRole$eaa05a502d0ede18(_jc_env *, struct _jc_javax_swing_JRadioButton__24AccessibleJRadioButton$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_JRadioButton__24AccessibleJRadioButton$method_info$getAccessibleRole$eaa05a502d0ede18;

// Virtual methods structure
struct _jc_javax_swing_JRadioButton__24AccessibleJRadioButton$vmethods {
	struct _jc_javax_accessibility_AccessibleRole$object	*(*getAccessibleRole$eaa05a502d0ede18)(_jc_env *, struct _jc_javax_swing_JRadioButton__24AccessibleJRadioButton$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_JRadioButton__24AccessibleJRadioButton$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_accessibility_AccessibleContext$vmethods	javax_accessibility_AccessibleContext;
	_jc_java_awt_Component__24AccessibleAWTComponent$vmethods	java_awt_Component__24AccessibleAWTComponent;
	_jc_java_awt_Container__24AccessibleAWTContainer$vmethods	java_awt_Container__24AccessibleAWTContainer;
	_jc_javax_swing_JComponent__24AccessibleJComponent$vmethods	javax_swing_JComponent__24AccessibleJComponent;
	_jc_javax_swing_AbstractButton__24AccessibleAbstractButton$vmethods	javax_swing_AbstractButton__24AccessibleAbstractButton;
	_jc_javax_swing_JToggleButton__24AccessibleJToggleButton$vmethods	javax_swing_JToggleButton__24AccessibleJToggleButton;
	_jc_javax_swing_JRadioButton__24AccessibleJRadioButton$vmethods	javax_swing_JRadioButton__24AccessibleJRadioButton;
};

// Vtype
struct _jc_javax_swing_JRadioButton__24AccessibleJRadioButton$vtype {
	_jc_type			type;
	_jc_javax_swing_JRadioButton__24AccessibleJRadioButton$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_JRadioButton__24AccessibleJRadioButton$sub_refs {
	struct _jc_javax_swing_JRadioButton$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_JRadioButton__24AccessibleJRadioButton$refs {
    _jc_javax_swing_JRadioButton__24AccessibleJRadioButton$sub_refs	javax_swing_JRadioButton__24AccessibleJRadioButton;
    _jc_javax_swing_JToggleButton__24AccessibleJToggleButton$sub_refs	javax_swing_JToggleButton__24AccessibleJToggleButton;
    _jc_javax_swing_AbstractButton__24AccessibleAbstractButton$sub_refs	javax_swing_AbstractButton__24AccessibleAbstractButton;
    _jc_javax_swing_JComponent__24AccessibleJComponent$sub_refs	javax_swing_JComponent__24AccessibleJComponent;
    _jc_java_awt_Container__24AccessibleAWTContainer$sub_refs	java_awt_Container__24AccessibleAWTContainer;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_refs	java_awt_Component__24AccessibleAWTComponent;
    _jc_javax_accessibility_AccessibleContext$sub_refs	javax_accessibility_AccessibleContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_JRadioButton__24AccessibleJRadioButton$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_JRadioButton__24AccessibleJRadioButton$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_accessibility_AccessibleContext$sub_nonrefs	javax_accessibility_AccessibleContext;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_nonrefs	java_awt_Component__24AccessibleAWTComponent;
    _jc_java_awt_Container__24AccessibleAWTContainer$sub_nonrefs	java_awt_Container__24AccessibleAWTContainer;
    _jc_javax_swing_JComponent__24AccessibleJComponent$sub_nonrefs	javax_swing_JComponent__24AccessibleJComponent;
    _jc_javax_swing_AbstractButton__24AccessibleAbstractButton$sub_nonrefs	javax_swing_AbstractButton__24AccessibleAbstractButton;
    _jc_javax_swing_JToggleButton__24AccessibleJToggleButton$sub_nonrefs	javax_swing_JToggleButton__24AccessibleJToggleButton;
    _jc_javax_swing_JRadioButton__24AccessibleJRadioButton$sub_nonrefs	javax_swing_JRadioButton__24AccessibleJRadioButton;
};

// Object instance structure
struct _jc_javax_swing_JRadioButton__24AccessibleJRadioButton$object {
	_jc_javax_swing_JRadioButton__24AccessibleJRadioButton$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_JRadioButton__24AccessibleJRadioButton$vtype	*vtype;
	_jc_javax_swing_JRadioButton__24AccessibleJRadioButton$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_JRadioButton__24AccessibleJRadioButton$vtype _jc_javax_swing_JRadioButton__24AccessibleJRadioButton$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_JRadioButton__24AccessibleJRadioButton, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_JRadioButton__24AccessibleJRadioButton$class_object;

#endif	/* _JC_javax_swing_JRadioButton__24AccessibleJRadioButton_H_ */
